# coding: utf-8

# flake8: noqa

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.06.25
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import


# import apis into sdk package
from agilicus_api.api.application_services_api import ApplicationServicesApi
from agilicus_api.api.applications_api import ApplicationsApi
from agilicus_api.api.audits_api import AuditsApi
from agilicus_api.api.catalogues_api import CataloguesApi
from agilicus_api.api.challenges_api import ChallengesApi
from agilicus_api.api.diagnostics_api import DiagnosticsApi
from agilicus_api.api.files_api import FilesApi
from agilicus_api.api.groups_api import GroupsApi
from agilicus_api.api.issuers_api import IssuersApi
from agilicus_api.api.messages_api import MessagesApi
from agilicus_api.api.metrics_api import MetricsApi
from agilicus_api.api.organisations_api import OrganisationsApi
from agilicus_api.api.permissions_api import PermissionsApi
from agilicus_api.api.services_api import ServicesApi
from agilicus_api.api.tokens_api import TokensApi
from agilicus_api.api.users_api import UsersApi
from agilicus_api.api.whoami_api import WhoamiApi

# import ApiClient
from agilicus_api.api_client import ApiClient
from agilicus_api.configuration import Configuration
from agilicus_api.exceptions import OpenApiException
from agilicus_api.exceptions import ApiTypeError
from agilicus_api.exceptions import ApiValueError
from agilicus_api.exceptions import ApiKeyError
from agilicus_api.exceptions import ApiException
# import models into sdk package
from agilicus_api.models.add_group_member_request import AddGroupMemberRequest
from agilicus_api.models.application import Application
from agilicus_api.models.application_assignment import ApplicationAssignment
from agilicus_api.models.application_service import ApplicationService
from agilicus_api.models.application_service_assignment import ApplicationServiceAssignment
from agilicus_api.models.audit import Audit
from agilicus_api.models.catalogue import Catalogue
from agilicus_api.models.catalogue_entry import CatalogueEntry
from agilicus_api.models.challenge import Challenge
from agilicus_api.models.challenge_answer import ChallengeAnswer
from agilicus_api.models.challenge_answer_spec import ChallengeAnswerSpec
from agilicus_api.models.challenge_spec import ChallengeSpec
from agilicus_api.models.challenge_status import ChallengeStatus
from agilicus_api.models.combined_rules import CombinedRules
from agilicus_api.models.combined_rules_status import CombinedRulesStatus
from agilicus_api.models.common_metadata import CommonMetadata
from agilicus_api.models.create_token_request import CreateTokenRequest
from agilicus_api.models.definition import Definition
from agilicus_api.models.environment import Environment
from agilicus_api.models.environment_config import EnvironmentConfig
from agilicus_api.models.environment_config_var import EnvironmentConfigVar
from agilicus_api.models.environment_status import EnvironmentStatus
from agilicus_api.models.error_message import ErrorMessage
from agilicus_api.models.file import File
from agilicus_api.models.file_summary import FileSummary
from agilicus_api.models.file_upload import FileUpload
from agilicus_api.models.group import Group
from agilicus_api.models.group_data import GroupData
from agilicus_api.models.group_member import GroupMember
from agilicus_api.models.host_permissions import HostPermissions
from agilicus_api.models.http_rule import HttpRule
from agilicus_api.models.included_role import IncludedRole
from agilicus_api.models.issuer import Issuer
from agilicus_api.models.issuer_client import IssuerClient
from agilicus_api.models.json_body_constraint import JSONBodyConstraint
from agilicus_api.models.list_active_users_response import ListActiveUsersResponse
from agilicus_api.models.list_application_services_response import ListApplicationServicesResponse
from agilicus_api.models.list_applications_response import ListApplicationsResponse
from agilicus_api.models.list_audits_response import ListAuditsResponse
from agilicus_api.models.list_catalogue_entries_response import ListCatalogueEntriesResponse
from agilicus_api.models.list_catalogues_response import ListCataloguesResponse
from agilicus_api.models.list_combined_rules_response import ListCombinedRulesResponse
from agilicus_api.models.list_configs_response import ListConfigsResponse
from agilicus_api.models.list_elevated_user_roles import ListElevatedUserRoles
from agilicus_api.models.list_environment_configs_response import ListEnvironmentConfigsResponse
from agilicus_api.models.list_files_response import ListFilesResponse
from agilicus_api.models.list_groups_response import ListGroupsResponse
from agilicus_api.models.list_issuer_clients_response import ListIssuerClientsResponse
from agilicus_api.models.list_issuer_extensions_response import ListIssuerExtensionsResponse
from agilicus_api.models.list_issuer_roots_response import ListIssuerRootsResponse
from agilicus_api.models.list_logs_response import ListLogsResponse
from agilicus_api.models.list_message_users_response import ListMessageUsersResponse
from agilicus_api.models.list_orgs_response import ListOrgsResponse
from agilicus_api.models.list_role_to_rule_entries import ListRoleToRuleEntries
from agilicus_api.models.list_roles import ListRoles
from agilicus_api.models.list_rules import ListRules
from agilicus_api.models.list_services_response import ListServicesResponse
from agilicus_api.models.list_tokens_response import ListTokensResponse
from agilicus_api.models.list_top_users_response import ListTopUsersResponse
from agilicus_api.models.list_user_guids_response import ListUserGuidsResponse
from agilicus_api.models.list_users_response import ListUsersResponse
from agilicus_api.models.log import Log
from agilicus_api.models.managed_upstream_identity_provider import ManagedUpstreamIdentityProvider
from agilicus_api.models.message import Message
from agilicus_api.models.message_action import MessageAction
from agilicus_api.models.message_endpoint import MessageEndpoint
from agilicus_api.models.message_endpoint_type import MessageEndpointType
from agilicus_api.models.message_user import MessageUser
from agilicus_api.models.message_user_spec import MessageUserSpec
from agilicus_api.models.metadata_with_id import MetadataWithId
from agilicus_api.models.metadata_with_id_all_of import MetadataWithIdAllOf
from agilicus_api.models.oidc_upstream_identity_provider import OIDCUpstreamIdentityProvider
from agilicus_api.models.organisation import Organisation
from agilicus_api.models.organisation_admin import OrganisationAdmin
from agilicus_api.models.raw_token import RawToken
from agilicus_api.models.rendered_query_parameter import RenderedQueryParameter
from agilicus_api.models.rendered_rule import RenderedRule
from agilicus_api.models.rendered_rule_body import RenderedRuleBody
from agilicus_api.models.replace_user_role_request import ReplaceUserRoleRequest
from agilicus_api.models.role import Role
from agilicus_api.models.role_list import RoleList
from agilicus_api.models.role_spec import RoleSpec
from agilicus_api.models.role_to_rule_entry import RoleToRuleEntry
from agilicus_api.models.role_to_rule_entry_spec import RoleToRuleEntrySpec
from agilicus_api.models.role_v2 import RoleV2
from agilicus_api.models.roles import Roles
from agilicus_api.models.rule import Rule
from agilicus_api.models.rule_query_body import RuleQueryBody
from agilicus_api.models.rule_query_body_json import RuleQueryBodyJSON
from agilicus_api.models.rule_query_parameter import RuleQueryParameter
from agilicus_api.models.rule_scope import RuleScope
from agilicus_api.models.rule_scope_enum import RuleScopeEnum
from agilicus_api.models.rule_scope_enum_list import RuleScopeEnumList
from agilicus_api.models.rule_spec import RuleSpec
from agilicus_api.models.rule_v2 import RuleV2
from agilicus_api.models.runtime_status import RuntimeStatus
from agilicus_api.models.service import Service
from agilicus_api.models.storage_region import StorageRegion
from agilicus_api.models.time_interval_metrics import TimeIntervalMetrics
from agilicus_api.models.time_validity import TimeValidity
from agilicus_api.models.token import Token
from agilicus_api.models.token_introspect import TokenIntrospect
from agilicus_api.models.token_introspect_options import TokenIntrospectOptions
from agilicus_api.models.token_reissue_request import TokenReissueRequest
from agilicus_api.models.token_revoke import TokenRevoke
from agilicus_api.models.token_validity import TokenValidity
from agilicus_api.models.user import User
from agilicus_api.models.user_identity import UserIdentity
from agilicus_api.models.user_info import UserInfo
from agilicus_api.models.user_member_of import UserMemberOf
from agilicus_api.models.user_metrics import UserMetrics
from agilicus_api.models.user_roles import UserRoles
from agilicus_api.models.user_summary import UserSummary
from agilicus_api.models.whoami_request import WhoamiRequest
from agilicus_api.models.whoami_response import WhoamiResponse




# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.06.25
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.application import Application  # noqa: E501
from agilicus_api.rest import ApiException

class TestApplication(unittest.TestCase):
    """Application unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Application
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.application.Application()  # noqa: E501
        if include_optional :
            return Application(
                created = '2015-07-07T15:49:51.230+02:00', 
                id = '123', 
                name = 'a', 
                description = '0', 
                category = '0', 
                image = '0', 
                image_username = '0', 
                image_password = '0', 
                image_credentials_type = 'basic_auth', 
                environments = [
                    agilicus_api.models.environment.Environment(
                        created = '2015-07-07T15:49:51.230+02:00', 
                        name = '0', 
                        maintenance_org_id = '0', 
                        version_tag = '0', 
                        config_mount_path = '0', 
                        config_as_mount = '0', 
                        config_as_env = '0', 
                        secrets_mount_path = '0', 
                        secrets_as_mount = '0', 
                        secrets_as_env = '0', 
                        application_services = [
                            agilicus_api.models.application_service.ApplicationService(
                                id = '123', 
                                name = '0', 
                                org_id = '0', 
                                hostname = 'db.example.com', 
                                ipv4_addresses = [
                                    '192.0.2.1'
                                    ], 
                                name_resolution = 'static', 
                                port = 56, 
                                protocol = 'tcp', 
                                assignments = [
                                    agilicus_api.models.application_service_assignment.ApplicationServiceAssignment(
                                        app_id = '0', 
                                        environment_name = '0', 
                                        org_id = '0', )
                                    ], 
                                updated = '2015-07-07T15:49:51.230+02:00', )
                            ], 
                        serverless_image = '0', 
                        status = agilicus_api.models.environment_status.EnvironmentStatus(
                            runtime_status = agilicus_api.models.runtime_status.RuntimeStatus(
                                overall_status = 'good', 
                                running_replicas = 2, 
                                error_message = 'CrashLoopBackoff', 
                                restarts = 5, 
                                cpu = 0.6, 
                                memory = 45.2, 
                                last_apply_time = '2020-06-19T15:35:08Z', 
                                running_image = 'cr.agilicus.com/applications/iomad:v1.13.0', 
                                running_hash = 'sha256:2fb759c1adfe40863b89a4076111af8f210e7342d2240f09b08fc445b357112e', 
                                org_id = '123', ), ), 
                        updated = '2015-07-07T15:49:51.230+02:00', )
                    ], 
                org_id = '0', 
                contact_email = '0', 
                port = 56, 
                healthcheck_uri = '0', 
                roles = [
                    agilicus_api.models.role.Role(
                        name = '0', 
                        rules = [
                            agilicus_api.models.rule.Rule(
                                host = '0', 
                                name = 'rules.add', 
                                method = 'get', 
                                path = '/.*', 
                                query_parameters = [
                                    agilicus_api.models.rule_query_parameter.RuleQueryParameter(
                                        name = '0', 
                                        exact_match = '0', )
                                    ], 
                                body = agilicus_api.models.rule_query_body.RuleQueryBody(
                                    json = [
                                        agilicus_api.models.rule_query_body_json.RuleQueryBodyJSON(
                                            name = '0', 
                                            exact_match = '0', 
                                            match_type = 'string', 
                                            pointer = '/foo/0/a~1b/2', )
                                        ], ), )
                            ], )
                    ], 
                definitions = [
                    agilicus_api.models.definition.Definition(
                        key = '0', 
                        value = '0', )
                    ], 
                assignments = [
                    agilicus_api.models.application_assignment.ApplicationAssignment(
                        id = '0', 
                        org_id = 'asd901laskbh', 
                        environment_name = 'production', 
                        application_name = 'Blogs', )
                    ], 
                owned = True, 
                maintained = True, 
                assigned = True, 
                updated = '2015-07-07T15:49:51.230+02:00'
            )
        else :
            return Application(
                name = 'a',
                category = '0',
                org_id = '0',
        )

    def testApplication(self):
        """Test Application"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.06.25
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_catalogue_entries_response import ListCatalogueEntriesResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListCatalogueEntriesResponse(unittest.TestCase):
    """ListCatalogueEntriesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListCatalogueEntriesResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_catalogue_entries_response.ListCatalogueEntriesResponse()  # noqa: E501
        if include_optional :
            return ListCatalogueEntriesResponse(
                catalogue_entries = [
                    agilicus_api.models.catalogue_entry.CatalogueEntry(
                        id = '123', 
                        catalogue_id = '123', 
                        catalogue_category = '0', 
                        name = 'dotnet_core', 
                        content = 'cr.agilicus.com/dotnet_core/app-image:latest', 
                        tag = 'V1.1', 
                        short_description = '0', 
                        long_description = '0', 
                        created = '2015-07-07T15:49:51.230+02:00', 
                        updated = '2015-07-07T15:49:51.230+02:00', )
                    ], 
                limit = 56
            )
        else :
            return ListCatalogueEntriesResponse(
                limit = 56,
        )

    def testListCatalogueEntriesResponse(self):
        """Test ListCatalogueEntriesResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



import agilicus

from . import context


def create_challenge(ctx, user_id, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)

    spec = agilicus.ChallengeSpec(user_id=user_id, **kwargs)
    challenge = agilicus.Challenge(spec=spec)

    resp = apiclient.challenges_api.create_challenge(challenge)
    return resp


def replace_challenge(ctx, challenge_id, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)

    existing = apiclient.challenges_api.get_challenge(challenge_id)

    spec_as_dict = existing.spec.to_dict()
    spec_as_dict.update(kwargs)
    spec = agilicus.ChallengeSpec(**spec_as_dict)
    existing.spec = spec

    resp = apiclient.challenges_api.replace_challenge(challenge_id, existing)
    return resp


def get_challenge(ctx, challenge_id, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)

    resp = apiclient.challenges_api.get_challenge(challenge_id)
    return resp


def delete_challenge(ctx, challenge_id, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)

    resp = apiclient.challenges_api.delete_challenge(challenge_id)
    return resp



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.06.25
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.messages_api import MessagesApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestMessagesApi(unittest.TestCase):
    """MessagesApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.messages_api.MessagesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_message(self):
        """Test case for create_message

        Create a message (to a user)  # noqa: E501
        """
        pass

    def test_create_message_user(self):
        """Test case for create_message_user

        create a user with messaging endpoints  # noqa: E501
        """
        pass

    def test_list_message_users(self):
        """Test case for list_message_users

        List all users  # noqa: E501
        """
        pass

    def test_replace_message_user(self):
        """Test case for replace_message_user

        update a user with messaging endpoints  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
